/**
 * 对象深拷贝函数
 * @param obj 需要拷贝的对象
 * @returns 拷贝后的新对象
 */
export function deepCopy<T>(obj: T): T {
    // 首先判断 obj 是否为引用类型或者数组
    if (typeof obj !== 'object' || obj === null) {
        return obj
    }

    // 处理数组
    if (Array.isArray(obj)) {
        return obj.map((item) => deepCopy(item)) as unknown as T
    }

    // 处理对象
    const copiedObj = {} as T
    for (const key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
            copiedObj[key] = deepCopy((obj as any)[key])
        }
    }

    return copiedObj
}

/**
 * 把对象中的空值清除掉
 * @param parameters 要处理的对象
 * @returns 处理后的对象
 */
export function paramsHandling(parameters: Record<string, any>): Record<string, any> {
    const Params: Record<string, any> = {}

    for (const [key, value] of Object.entries(parameters)) {
        if (value !== '' && value !== null && !Object.is(value, NaN)) {
            Params[key] = typeof value === 'string' ? value.trim() : value
        } else {
            Params[key] = undefined
        }
    }

    return Params
}

/**
 * 根据键的属性从 row 对象中提取该键的值
 * @param row 需要处理的对象
 * @param keys 需要设置的键
 * @returns 处理后的对象
 */
export function rowKeyHandling(row: Record<string, any>, keys: string | string[]) {
    let keyParams: Record<string, any> = {}

    if (typeof keys === 'string') {
        keyParams[keys] = row[keys]
    } else {
        keys.forEach((key) => {
            keyParams[key] = row[key]
        })
    }

    return keyParams
}

/**
 * 比较两个 Obj 的值是否修改
 * @param obj1 原obj
 * @param obj2 新obj
 * @returns 修改过的obj
 */
export function isObjEqual(obj1: any, obj2: any) {
    let res: any = {}

    let aProps = Object.getOwnPropertyNames(obj1)
    let bProps = Object.getOwnPropertyNames(obj2)

    // if (aProps.length === bProps.length) {
    //循环拿到数值进行对比
    bProps.forEach((e) => {
        if (obj1[e] !== obj2[e]) res[e] = obj2[e]
    })
    // }

    return res
}
